import { useState } from "react";
import { Settings } from "../../lib/settings";
import Header from "../navigation/Header";
import LoginForm from "./LoginForm";
import { LogoutContext } from "../../lib/LogoutContext";
import { RefreshContext } from "../../lib/RefreshContext";
import TabView from "../TabView";

export default function AuthWrapper() {
  const [isConfigured, setIsConfigured] = useState(
    Boolean(Settings.getServiceUrl() && Settings.getAdminPassword()),
  );
  const [lastUpdate, setLastUpdate] = useState(Date.now());

  const handleLogout = () => {
    Settings.clearSettings();
    setIsConfigured(false);
  };

  const refresh = () => {
    setLastUpdate(Date.now());
  };

  if (!isConfigured) {
    return <LoginForm onLogin={() => setIsConfigured(true)} />;
  }

  return (
    <LogoutContext.Provider value={handleLogout}>
      <RefreshContext.Provider value={{ refresh, lastUpdate }}>
        <div className="w-full flex flex-col">
          <Header />
          <div className="min-h-[calc(100vh-64px)] p-4">
            <div className="container mx-auto">
              <TabView />
            </div>
          </div>
        </div>
      </RefreshContext.Provider>
    </LogoutContext.Provider>
  );
}
