import { useState } from "react";
import { Settings } from "../../lib/settings";

interface LoginFormProps {
  onLogin: () => void;
}

export default function LoginForm({ onLogin }: LoginFormProps) {
  const [serviceUrl, setServiceUrl] = useState("");
  const [adminPassword, setAdminPassword] = useState("");

  const handleSubmit = (e: React.FormEvent) => {
    e.preventDefault();
    Settings.saveSettings(serviceUrl, adminPassword);
    onLogin();
  };

  return (
    <div className="w-full container mx-auto max-w-md p-4">
      <div className="card bg-base-100 shadow-xl">
        <div className="card-body">
          <h1 className="card-title text-2xl font-bold text-center">
            BlueSky PDS Manager
          </h1>
          <p className="text-center text-base-content/70 mb-4">
            Enter your PDS credentials to get started
          </p>
          <form onSubmit={handleSubmit} className="space-y-4">
            <div className="form-control w-full">
              <label className="label">
                <span className="label-text">PDS URL</span>
              </label>
              <input
                type="url"
                value={serviceUrl}
                onChange={(e) => setServiceUrl(e.target.value)}
                placeholder="https://bsky.web.site"
                required
                className="input input-bordered w-full"
              />
            </div>
            <div className="form-control w-full">
              <label className="label">
                <span className="label-text">Admin Password</span>
              </label>
              <input
                type="password"
                value={adminPassword}
                onChange={(e) => setAdminPassword(e.target.value)}
                required
                className="input input-bordered w-full"
              />
            </div>
            <div className="divider"></div>
            <button type="submit" className="btn btn-primary w-full">
              Connect to PDS
            </button>
          </form>
        </div>
      </div>
    </div>
  );
}
