import { useLogout } from "../../lib/LogoutContext";
import { useRefresh } from "../../lib/RefreshContext";
import { useState } from "react";
import { Settings } from "../../lib/settings";

export default function NavBar() {
  const logout = useLogout();
  const { refresh } = useRefresh();
  const [showSettings, setShowSettings] = useState(false);
  const [newUrl, setNewUrl] = useState(Settings.getServiceUrl());
  const [newPassword, setNewPassword] = useState(Settings.getAdminPassword());

  const saveSettings = () => {
    Settings.saveSettings(newUrl, newPassword);
    setShowSettings(false);
    refresh();
  };

  return (
    <>
      <div className="w-full navbar bg-base-100 shadow-md">
        <div className="container mx-auto max-w-3xl px-4">
          <div className="flex-1">
            <span className="text-xl font-bold">BlueSky PDS Manager</span>
          </div>
          <div className="flex-none">
            {/* Regular buttons for larger screens */}
            <div className="hidden sm:flex items-center gap-2">
              <button
                onClick={() => setShowSettings(true)}
                className="btn btn-ghost"
              >
                ⚙️ Settings
              </button>
              <button onClick={logout} className="btn btn-ghost text-error">
                🚪 Logout
              </button>
            </div>

            {/* Dropdown for mobile */}
            <div className="dropdown dropdown-end sm:hidden">
              <label tabIndex={0} className="btn btn-ghost btn-circle">
                <svg
                  xmlns="http://www.w3.org/2000/svg"
                  fill="none"
                  viewBox="0 0 24 24"
                  className="inline-block w-5 h-5 stroke-current"
                >
                  <path
                    strokeLinecap="round"
                    strokeLinejoin="round"
                    strokeWidth="2"
                    d="M5 12h.01M12 12h.01M19 12h.01M6 12a1 1 0 11-2 0 1 1 0 012 0zm7 0a1 1 0 11-2 0 1 1 0 012 0zm7 0a1 1 0 11-2 0 1 1 0 012 0z"
                  />
                </svg>
              </label>
              <ul
                tabIndex={0}
                className="dropdown-content z-[1] menu p-2 shadow bg-base-100 rounded-box w-52"
              >
                <li>
                  <button onClick={() => setShowSettings(true)}>
                    ⚙️ Settings
                  </button>
                </li>
                <li>
                  <button onClick={logout} className="text-error">
                    🚪 Logout
                  </button>
                </li>
              </ul>
            </div>
          </div>
        </div>
      </div>

      {/* Settings Modal */}
      <dialog className={`modal ${showSettings ? "modal-open" : ""}`}>
        <div className="modal-box">
          <h3 className="font-bold text-lg mb-4">PDS Settings</h3>
          <div className="form-control w-full">
            <label className="label">
              <span className="label-text">PDS URL</span>
            </label>
            <input
              type="url"
              value={newUrl}
              onChange={(e) => setNewUrl(e.target.value)}
              className="input input-bordered w-full"
              placeholder="https://bsky.atri.dad"
            />
          </div>
          <div className="form-control w-full mt-4">
            <label className="label">
              <span className="label-text">Admin Password</span>
            </label>
            <input
              type="password"
              value={newPassword}
              onChange={(e) => setNewPassword(e.target.value)}
              className="input input-bordered w-full"
            />
          </div>
          <div className="modal-action">
            <button onClick={() => setShowSettings(false)} className="btn">
              Cancel
            </button>
            <button onClick={saveSettings} className="btn btn-primary">
              Save
            </button>
          </div>
        </div>
        <form method="dialog" className="modal-backdrop">
          <button onClick={() => setShowSettings(false)}>close</button>
        </form>
      </dialog>
    </>
  );
}
